pm4py.statistics.eventually\_follows.pandas package
===================================================

Submodules
----------

pm4py.statistics.eventually\_follows.pandas.get module
------------------------------------------------------

.. automodule:: pm4py.statistics.eventually_follows.pandas.get
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.statistics.eventually_follows.pandas
   :members:
   :undoc-members:
   :show-inheritance:
